@@ -1,7 +1,7 @@
 package DBIx::Custom;
 use Object::Simple -base;
 
-our $VERSION = '0.1717';
+our $VERSION = '0.1718';
 use 5.008001;
 
 use Carp 'croak';
@@ -186,6 +186,8 @@ sub connect {
     return $self;
 }
 
+sub count { shift->select(column => 'count(*)', @_)->fetch_first->[0] }
+
 sub dbh {
     my $self = shift;
     
@@ -813,7 +815,7 @@ sub new {
     # Check attributes
     my @attrs = keys %$self;
     foreach my $attr (@attrs) {
-        croak qq{"$attr" is wrong name } . _subname
+        croak qq{Invalid attribute: "$attr" } . _subname
           unless $self->can($attr);
     }
 
@@ -1903,7 +1905,7 @@ sub _add_relation_table {
 
 DBIx::Custom - Execute insert, update, delete, and select statement easily
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
     use DBIx::Custom;
     
@@ -1957,7 +1959,7 @@ DBIx::Custom - Execute insert, update, delete, and select statement easily
         {author => 'ken', title => '%Perl%'}
     );
     
-=head1 DESCRIPTIONS
+=head1 DESCRIPTION
 
 L<DBIx::Custom> is L<DBI> wrapper module to execute SQL easily.
 This module have the following features.
@@ -2000,7 +2002,7 @@ Create C<order by> clause flexibly(EXPERIMENTAL)
 
 =back
 
-=head1 DOCUMENTATIONS
+=head1 DOCUMENTATION
 
 L<DBIx::Custom::Guide> - How to use L<DBIx::Custom>
 
@@ -2281,7 +2283,15 @@ L<DBIx::Custom> is a wrapper of L<DBI>.
 C<AutoCommit> and C<RaiseError> options are true, 
 and C<PrintError> option is false by default.
 
-=head2 create_model
+=head2 C<count> EXPERIMENTAL
+
+    my $count = $model->count(table => 'book');
+
+Get rows count.
+
+Options is same as C<select> method's ones.
+
+=head2 C<create_model>
 
     my $model = $dbi->create_model(
         table => 'book',
@@ -3352,7 +3362,7 @@ Create a new L<DBIx::Custom::Where> object.
 Setup all model objects.
 C<columns> of model object is automatically set, parsing database information.
 
-=head1 ENVIRONMENT VARIABLE
+=head1 ENVIRONMENTAL VARIABLES
 
 =head2 C<DBIX_CUSTOM_DEBUG>
 
@@ -3393,7 +3403,7 @@ This type name is used in C<type_rule>'s C<into1> and C<into2>.
 
 DEBUG output encoding. Default to UTF-8.
 
-=head1 DEPRECATED FUNCTIONALITIES
+=head1 DEPRECATED FUNCTIONALITY
 
 L<DBIx::Custom>
 
@@ -3477,7 +3487,7 @@ L<DBIx::Custom::Tag>
 
     This module is DEPRECATED! # will be removed at 2017/1/1
 
-=head1 BACKWORD COMPATIBLE POLICY
+=head1 BACKWARDS COMPATIBILITY POLICY
 
 If a functionality is DEPRECATED, you can know it by DEPRECATED warnings
 except for attribute method.
